@@ -361,7 +361,8 @@ AFFILE *af_open(const char *filename,int flags,int mode)
 	return 0;
     }
 
-    if(flags & O_WRONLY){
+    /* Note on Hurd O_RDWR == O_WRONLY|O_RDONLY, so checking just (flags & O_WRONLY) does not work */
+    if((flags & O_ACCMODE) == O_WRONLY){
 	errno = EINVAL;
 	return 0;			// this flag not supported
     }
@@ -806,6 +807,7 @@ int af_update_segf(AFFILE *af, const char *segname,
 #ifdef HAVE_AES_ENCRYPT
     const char *oldname = 0;
     unsigned char *newdata = 0;
+    char aesname[AF_MAX_NAME_LEN];
     if(AF_SEALING(af) && ((flag & AF_SIGFLAG_NOSEAL)==0) && af->crypto->auto_encrypt){
 	/* Create an IV */
 	unsigned char iv[AES_BLOCK_SIZE];
@@ -813,7 +815,6 @@ int af_update_segf(AFFILE *af, const char *segname,
 	strlcpy((char *)iv,segname,sizeof(iv));
 
 	/* Figure out the real segment name */
-	char aesname[AF_MAX_NAME_LEN];
 	strlcpy(aesname,segname,sizeof(aesname));
 	strlcat(aesname,AF_AES256_SUFFIX,sizeof(aesname));
 	oldname = segname;
